@@ -1,5 +1,4 @@
 <?php
-
 namespace PhpAmqpLib\Exception;
 
 //TODO refactor usage of static methods
@@ -8,17 +7,23 @@ use PhpAmqpLib\Helper\MiscHelper;
 
 class AMQPProtocolException extends \Exception implements AMQPExceptionInterface
 {
-
+    /** @var string */
     public $amqp_reply_code;
 
+    /** @var int */
     public $amqp_reply_text;
 
+    /** @var \Exception */
     public $amqp_method_sig;
 
+    /** @var array */
     public $args;
 
-
-
+    /**
+     * @param string $reply_code
+     * @param int $reply_text
+     * @param array $method_sig
+     */
     public function __construct($reply_code, $reply_text, $method_sig)
     {
         parent::__construct($reply_text, $reply_code);
@@ -29,12 +34,11 @@ class AMQPProtocolException extends \Exception implements AMQPExceptionInterface
 
         $ms = MiscHelper::methodSig($method_sig);
 
-        $PROTOCOL_CONSTANTS_CLASS = AbstractChannel::$PROTOCOL_CONSTANTS_CLASS;
-        $mn = isset($PROTOCOL_CONSTANTS_CLASS::$GLOBAL_METHOD_NAMES[$ms])
-            ? $PROTOCOL_CONSTANTS_CLASS::$GLOBAL_METHOD_NAMES[$ms]
-            : $mn = "";
+        $protocolClass = AbstractChannel::$PROTOCOL_CONSTANTS_CLASS;
+        $mn = isset($protocolClass::$GLOBAL_METHOD_NAMES[$ms])
+            ? $protocolClass::$GLOBAL_METHOD_NAMES[$ms]
+            : $mn = '';
 
         $this->args = array($reply_code, $reply_text, $method_sig, $mn);
     }
-
 }
