@@ -42,6 +42,9 @@ class StreamIO extends AbstractIO
     /** @var array */
     protected $last_error;
 
+    /** @var int */
+    private $initial_heartbeat;
+
     /** @var resource */
     private $sock;
 
@@ -81,6 +84,7 @@ class StreamIO extends AbstractIO
         $this->context = $context;
         $this->keepalive = $keepalive;
         $this->heartbeat = $heartbeat;
+        $this->initial_heartbeat = $heartbeat;
         $this->canSelectNull = true;
         $this->canDispatchPcntlSignal = $this->isPcntlSignalEnabled();
 
@@ -197,12 +201,12 @@ class StreamIO extends AbstractIO
      */
     public function read($len)
     {
+        $this->check_heartbeat();
+
         $read = 0;
         $data = '';
 
         while ($read < $len) {
-            $this->check_heartbeat();
-
             if (!is_resource($this->sock) || feof($this->sock)) {
                 throw new AMQPRuntimeException('Broken pipe or closed connection');
             }
@@ -278,7 +282,7 @@ class StreamIO extends AbstractIO
             // September 2002:
             // http://comments.gmane.org/gmane.comp.encryption.openssl.user/4361
             try {
-                $buffer = fwrite($this->sock, $data, 8192);
+                $buffer = fwrite($this->sock, mb_substr($data, $written, 8192, 'ASCII'), 8192);
             } catch (\ErrorException $e) {
                 restore_error_handler();
                 throw $e;
@@ -298,10 +302,6 @@ class StreamIO extends AbstractIO
             }
 
             $written += $buffer;
-
-            if ($buffer > 0) {
-                $data = mb_substr($data, $buffer, mb_strlen($data, 'ASCII') - $buffer, 'ASCII');
-            }
         }
 
         $this->last_write = microtime(true);
@@ -380,6 +380,8 @@ class StreamIO extends AbstractIO
             fclose($this->sock);
         }
         $this->sock = null;
+        $this->last_read = null;
+        $this->last_write = null;
     }
 
     /**
@@ -405,11 +407,17 @@ class StreamIO extends AbstractIO
      */
     public function select($sec, $usec)
     {
+        $this->check_heartbeat();
+
         $read = array($this->sock);
         $write = null;
         $except = null;
         $result = false;
 
+        if (defined('HHVM_VERSION')) {
+            $usec = is_int($usec) ? $usec : 0;
+        }
+
         set_error_handler(array($this, 'error_handler'));
         try {
             $result = stream_select($read, $write, $except, $sec, $usec);
@@ -459,4 +467,14 @@ class StreamIO extends AbstractIO
 
         return $this;
     }
+
+    /**
+     * @return $this
+     */
+    public function reenableHeartbeat()
+    {
+        $this->heartbeat = $this->initial_heartbeat;
+
+        return $this;
+    }
 }
